Bstatus template - BookLab
Author: Petre Iordanescu (petre.iordanescu@gmail.com)

Skip to content

# Detalii despre carte

Aici puteti consulta detaliile cartii {{ book_data.short_desc }} (cod `{{ book_data.code }}`).

## Date generale

- Cod: `{{ book_data.code }}`
- Titlu: `{{ book_data.short_desc }}`
- Descriere: `{{ book_data.description }}`
- Note: `{{ book_data.notes }}`
- Copyright: `{{ book_data.copyright }}`
- Autor: `{{ book_data.site_author }}`

## Date de stare

- Carte inchisa editarii: `{{book_data.closed}}`
- Creata de: `{{ book_data.created_by }}`
- Creata la data: `{{ book_data.created_date }}`
- Ultima actualizare: `{{book_data.last_update_date}}`
- Ultima generare carte: `{{book_data.last_build_date}}`

## Date locatii

- Locatia stocare: `{{book_data.store_location}}`
- Locatia previzualizare: `{{book_data.preview_url}}` (Previzualizare)
- Locatia publicare: `{{book_data.published_location}}`
- Sectiunea de navigare in carte: `{{book_data.nav_file_location}}`

## Date volumetrice

- Numar pagini fizice (fisiere): ...urmeaza...
- Numar pagini logice (intrari in meniu): ...urmeaza...
- Numar fisiere poze: ...urmeaza...

## Actiuni

Creare carte noua Previzualizare

Editare materiale Sectiuni carte

Generare carte Livrare carte

## Help

## Vedere avansata sectiunea nevigare

### Format JSON

    {{ nav.fjson }}

### Format YAML

NOTA: Acest fisier este generat automat in timpul executiei sistemului din fisierul JSON (de mai sus) care este considerat "primar / master".

    {{ nav.fyaml }}

Last update: October 28, 2025